* {
	color:		#111155;
	font-size:	12pt;
}

#outer tr td {
	vertical-align:	top;
}

.keywords, .utime {
	margin:	5px 0 5px 0;
	font-size:	10pt;
	font-weight:	700;
}

.keyword {
	display:		inline;
/*	background-color:	#ffcc33; */
	margin-left:		5px;
}

#last_docs, #hot_kws, #content, #tb_view {
	display:		block;
}

#sidebar {
	width:			140px;
	padding:		0 0 2px 0;
	line-height:		0px;
	border-color:		#9f7220;
	border-width:		0 1px 2px 1px;
	border-style:		solid;
	background-color:	#f0d29c;
}

#sidebar DIV {
	line-height:		1.2;
}

#hide_bar {
	  height:		0px;
	  float:		left;
	  margin-top:		-100px;
}

#last_docs, #hot_kws {
	width:			100%;
	border-width:		0px;
	border-style:		solid;
	border-color:		grey;
	padding:		0px;
	margin-bottom:		10px;
}

#sidebar .title {
	font-size:	1.2em;
	font-weight:		300;
	background-color:	#9f7220;
	color:		white;
	padding:	0.1em 0.2em 0.1em 0.2em;
}

#tb_view #note {
	width:			100%;
	border-width:		0px;
	border-style:		solid;
	border-color:		#005A9C;
	color:			#005A9C;
	padding:		0px;
	margin-bottom:		10px;
}

#last_docs, #hot_kws, #last_docs A, #hot_kws A {
	font-size:		0.85em;
}

#tb_view UL A {
	font-size:		0.75em;
}

#last_docs UL, #hot_kws UL {
	   list-style:		square inside;
	   padding-left:	5px;
	   margin-top:		2px;
	   margin-bottom:	2px;
	   line-height:		0.9em;
}

UL {
	   padding-left:	15pt;
	   margin-top:		2px;
	   margin-bottom:	2px;
}

#last_docs UL LI, #hot_kws UL LI {
	/* color:			#af5381; */
	color:			#0e470e;
	font-size:              0.8em;
	white-space:		nowrap;
	overflow:		hidden;
}

#content {
	width:			670px;
	margin:			0 15px 0 5px;
	padding:		0 15px 0 15px;
}

.creator, .keywords, .utime, .utime A, .title, .keyword A:link, .keyword A:visited {
	/* color:		#005A9C; */
	color:		#0e470e;
}

.keyword A, .utime A {
	font-size: 10pt;
	font-weight:	700;
	margin-right:	5px;
}

.title, .title A {
	font-size:	18pt;
	font-weight:	700;
	color:			rgb(30,31,110);
}

.creator {
	font-size:	10pt;
	font-weight:	700;
	display:	block;
	margin:		5px 0 5px 0;
}

.rawtext {
	 visibility:	hidden;
}

.text {
        line-height:	1.5;
	margin-top:	20px;
}

.text P {
}

.quote {
	padding:	0 0 0 5px;
	margin:		0 0 0 20px;
	font-style:	italic;
	border-width:	0 0 0 2px;
	border-style:	solid;
	border-color:	rgb(90,59,113);
}

.text pre, .error {
	margin-left:	20px;
	margin-right:	20px;
	border-style:	dashed;
	border-width:	1px;
	border-color:	rgb(90,59,113);
	background-color:	#f8f8f8;
	padding:	2px 5px 2px 5px;
	overflow:	auto;
}

.text pre, .text pre A {
	text-align:	left;
	font-size:	10pt;
}

.text pre span.code_kw {
      font-size:       10pt;
      color:  	       rgb(94,17,29);
}

.text pre span.code_func {
      font-size:       10pt;
      color:  	       rgb(30,31,110);
}

.text TR TD {
	border-style:	solid;
	border-width:	2px 0 0 0;
	border-color:	grey;
}

#comments {
	  margin:	20px 0 0 0;
}

.comment {
	 border-style:	solid;
	 border-width:	3px 1px 1px 1px;
	 border-color:	rgb(90,59,113);
	 margin:	0 0 15px 0;
	 padding:	2px 10px 2px 10px;
	 background:	#f0f0f0;
}

.comment .pdate {
	 float:	 	right;
	 left:		100px;
	 font-size:	10pt;
}

.comment .name *{
	 font-size:	10pt;
}

.comment .msg {
	 margin-left:	20px;
	 margin-top:	10px;
}

.comment .control A {
	 margin-left:	5px;
}

INPUT, TEXTAREA {
	border-style:	solid;
	border-width:	1px;
	border-color:	#9f7220;
	color:		#111155;
	font-size:	12pt;
	padding:	0px 0px 0px 0px;
	margin:		2px 4px 2px 0px;
	background-color:	#f0d29c;
}

A, .text A, #tb_view A {
	color:		#0e470e;
}

#last_docs A, #hot_kws A {
	color:		rgb(30,31,110);
	margin-right:	5px;
}

A:hover, .text A:hover, #last_docs A:hover, #hot_kws A:hover, #tb_view A:hover {
	color:		#0e470e;
}

H1, H1 A {
	font-size:	16pt;
	font-weight:	800;
	color:	#111155;
}

H2, H2 A {
	font-size:	14pt;
	font-weight:	800;
	color:		#111155;
/*	border:		0px;
	border-bottom:	1px;
	border-style:	dashed; */
}

H3, H3 A {
	font-size:	13pt;
	font-weight:	800;
	color:		#111155;
}

B, B A  {
	font-weight:	bold;
}

